@@ -16,6 +16,7 @@ def _get_kwargs(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -27,6 +28,7 @@ def _get_kwargs(
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -44,6 +46,8 @@ def _get_kwargs(
 
     params["label"] = label
 
+    params["worker"] = worker
+
     params["parent_job"] = parent_job
 
     params["script_path_exact"] = script_path_exact
@@ -74,6 +78,8 @@ def _get_kwargs(
 
     params["result"] = result
 
+    params["allow_wildcards"] = allow_wildcards
+
     params["tag"] = tag
 
     params["page"] = page
@@ -135,6 +141,7 @@ def sync_detailed(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -146,6 +153,7 @@ def sync_detailed(
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -161,6 +169,7 @@ def sync_detailed(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -172,6 +181,7 @@ def sync_detailed(
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -193,6 +203,7 @@ def sync_detailed(
         order_desc=order_desc,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -204,6 +215,7 @@ def sync_detailed(
         job_kinds=job_kinds,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -227,6 +239,7 @@ def sync(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -238,6 +251,7 @@ def sync(
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -253,6 +267,7 @@ def sync(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -264,6 +279,7 @@ def sync(
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -286,6 +302,7 @@ def sync(
         order_desc=order_desc,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -297,6 +314,7 @@ def sync(
         job_kinds=job_kinds,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -314,6 +332,7 @@ async def asyncio_detailed(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -325,6 +344,7 @@ async def asyncio_detailed(
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -340,6 +360,7 @@ async def asyncio_detailed(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -351,6 +372,7 @@ async def asyncio_detailed(
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -372,6 +394,7 @@ async def asyncio_detailed(
         order_desc=order_desc,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -383,6 +406,7 @@ async def asyncio_detailed(
         job_kinds=job_kinds,
         args=args,
         result=result,
+        allow_wildcards=allow_wildcards,
         tag=tag,
         page=page,
         per_page=per_page,
@@ -404,6 +428,7 @@ async def asyncio(
     order_desc: Union[Unset, None, bool] = UNSET,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -415,6 +440,7 @@ async def asyncio(
     job_kinds: Union[Unset, None, str] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
@@ -430,6 +456,7 @@ async def asyncio(
         order_desc (Union[Unset, None, bool]):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -441,6 +468,7 @@ async def asyncio(
         job_kinds (Union[Unset, None, str]):
         args (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         tag (Union[Unset, None, str]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
@@ -464,6 +492,7 @@ async def asyncio(
             order_desc=order_desc,
             created_by=created_by,
             label=label,
+            worker=worker,
             parent_job=parent_job,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
@@ -475,6 +504,7 @@ async def asyncio(
             job_kinds=job_kinds,
             args=args,
             result=result,
+            allow_wildcards=allow_wildcards,
             tag=tag,
             page=page,
             per_page=per_page,
