@@ -16,6 +16,7 @@ def _get_kwargs(
     *,
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -23,14 +24,19 @@ def _get_kwargs(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
+    suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
@@ -47,6 +53,8 @@ def _get_kwargs(
 
     params["label"] = label
 
+    params["worker"] = worker
+
     params["parent_job"] = parent_job
 
     params["script_path_exact"] = script_path_exact
@@ -69,6 +77,18 @@ def _get_kwargs(
 
     params["started_after"] = json_started_after
 
+    json_created_before: Union[Unset, None, str] = UNSET
+    if not isinstance(created_before, Unset):
+        json_created_before = created_before.isoformat() if created_before else None
+
+    params["created_before"] = json_created_before
+
+    json_created_after: Union[Unset, None, str] = UNSET
+    if not isinstance(created_after, Unset):
+        json_created_after = created_after.isoformat() if created_after else None
+
+    params["created_after"] = json_created_after
+
     json_created_or_started_before: Union[Unset, None, str] = UNSET
     if not isinstance(created_or_started_before, Unset):
         json_created_or_started_before = created_or_started_before.isoformat() if created_or_started_before else None
@@ -85,14 +105,26 @@ def _get_kwargs(
 
     params["created_or_started_after"] = json_created_or_started_after
 
+    json_created_or_started_after_completed_jobs: Union[Unset, None, str] = UNSET
+    if not isinstance(created_or_started_after_completed_jobs, Unset):
+        json_created_or_started_after_completed_jobs = (
+            created_or_started_after_completed_jobs.isoformat() if created_or_started_after_completed_jobs else None
+        )
+
+    params["created_or_started_after_completed_jobs"] = json_created_or_started_after_completed_jobs
+
     params["job_kinds"] = job_kinds
 
+    params["suspended"] = suspended
+
     params["args"] = args
 
     params["tag"] = tag
 
     params["result"] = result
 
+    params["allow_wildcards"] = allow_wildcards
+
     params["page"] = page
 
     params["per_page"] = per_page
@@ -173,6 +205,7 @@ def sync_detailed(
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -180,14 +213,19 @@ def sync_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
+    suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
@@ -203,6 +241,7 @@ def sync_detailed(
         workspace (str):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -210,14 +249,19 @@ def sync_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_before (Union[Unset, None, datetime.datetime]):
+        created_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
+        suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
@@ -239,6 +283,7 @@ def sync_detailed(
         workspace=workspace,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -246,14 +291,19 @@ def sync_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_before=created_before,
+        created_after=created_after,
         created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
+        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
+        suspended=suspended,
         args=args,
         tag=tag,
         result=result,
+        allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
         is_skipped=is_skipped,
@@ -277,6 +327,7 @@ def sync(
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -284,14 +335,19 @@ def sync(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
+    suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
@@ -307,6 +363,7 @@ def sync(
         workspace (str):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -314,14 +371,19 @@ def sync(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_before (Union[Unset, None, datetime.datetime]):
+        created_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
+        suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
@@ -344,6 +406,7 @@ def sync(
         client=client,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -351,14 +414,19 @@ def sync(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_before=created_before,
+        created_after=created_after,
         created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
+        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
+        suspended=suspended,
         args=args,
         tag=tag,
         result=result,
+        allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
         is_skipped=is_skipped,
@@ -376,6 +444,7 @@ async def asyncio_detailed(
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -383,14 +452,19 @@ async def asyncio_detailed(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
+    suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
@@ -406,6 +480,7 @@ async def asyncio_detailed(
         workspace (str):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -413,14 +488,19 @@ async def asyncio_detailed(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_before (Union[Unset, None, datetime.datetime]):
+        created_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
+        suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
@@ -442,6 +522,7 @@ async def asyncio_detailed(
         workspace=workspace,
         created_by=created_by,
         label=label,
+        worker=worker,
         parent_job=parent_job,
         script_path_exact=script_path_exact,
         script_path_start=script_path_start,
@@ -449,14 +530,19 @@ async def asyncio_detailed(
         script_hash=script_hash,
         started_before=started_before,
         started_after=started_after,
+        created_before=created_before,
+        created_after=created_after,
         created_or_started_before=created_or_started_before,
         running=running,
         scheduled_for_before_now=scheduled_for_before_now,
         created_or_started_after=created_or_started_after,
+        created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
         job_kinds=job_kinds,
+        suspended=suspended,
         args=args,
         tag=tag,
         result=result,
+        allow_wildcards=allow_wildcards,
         page=page,
         per_page=per_page,
         is_skipped=is_skipped,
@@ -478,6 +564,7 @@ async def asyncio(
     client: Union[AuthenticatedClient, Client],
     created_by: Union[Unset, None, str] = UNSET,
     label: Union[Unset, None, str] = UNSET,
+    worker: Union[Unset, None, str] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     script_path_exact: Union[Unset, None, str] = UNSET,
     script_path_start: Union[Unset, None, str] = UNSET,
@@ -485,14 +572,19 @@ async def asyncio(
     script_hash: Union[Unset, None, str] = UNSET,
     started_before: Union[Unset, None, datetime.datetime] = UNSET,
     started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_before: Union[Unset, None, datetime.datetime] = UNSET,
+    created_after: Union[Unset, None, datetime.datetime] = UNSET,
     created_or_started_before: Union[Unset, None, datetime.datetime] = UNSET,
     running: Union[Unset, None, bool] = UNSET,
     scheduled_for_before_now: Union[Unset, None, bool] = UNSET,
     created_or_started_after: Union[Unset, None, datetime.datetime] = UNSET,
+    created_or_started_after_completed_jobs: Union[Unset, None, datetime.datetime] = UNSET,
     job_kinds: Union[Unset, None, str] = UNSET,
+    suspended: Union[Unset, None, bool] = UNSET,
     args: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     result: Union[Unset, None, str] = UNSET,
+    allow_wildcards: Union[Unset, None, bool] = UNSET,
     page: Union[Unset, None, int] = UNSET,
     per_page: Union[Unset, None, int] = UNSET,
     is_skipped: Union[Unset, None, bool] = UNSET,
@@ -508,6 +600,7 @@ async def asyncio(
         workspace (str):
         created_by (Union[Unset, None, str]):
         label (Union[Unset, None, str]):
+        worker (Union[Unset, None, str]):
         parent_job (Union[Unset, None, str]):
         script_path_exact (Union[Unset, None, str]):
         script_path_start (Union[Unset, None, str]):
@@ -515,14 +608,19 @@ async def asyncio(
         script_hash (Union[Unset, None, str]):
         started_before (Union[Unset, None, datetime.datetime]):
         started_after (Union[Unset, None, datetime.datetime]):
+        created_before (Union[Unset, None, datetime.datetime]):
+        created_after (Union[Unset, None, datetime.datetime]):
         created_or_started_before (Union[Unset, None, datetime.datetime]):
         running (Union[Unset, None, bool]):
         scheduled_for_before_now (Union[Unset, None, bool]):
         created_or_started_after (Union[Unset, None, datetime.datetime]):
+        created_or_started_after_completed_jobs (Union[Unset, None, datetime.datetime]):
         job_kinds (Union[Unset, None, str]):
+        suspended (Union[Unset, None, bool]):
         args (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         result (Union[Unset, None, str]):
+        allow_wildcards (Union[Unset, None, bool]):
         page (Union[Unset, None, int]):
         per_page (Union[Unset, None, int]):
         is_skipped (Union[Unset, None, bool]):
@@ -546,6 +644,7 @@ async def asyncio(
             client=client,
             created_by=created_by,
             label=label,
+            worker=worker,
             parent_job=parent_job,
             script_path_exact=script_path_exact,
             script_path_start=script_path_start,
@@ -553,14 +652,19 @@ async def asyncio(
             script_hash=script_hash,
             started_before=started_before,
             started_after=started_after,
+            created_before=created_before,
+            created_after=created_after,
             created_or_started_before=created_or_started_before,
             running=running,
             scheduled_for_before_now=scheduled_for_before_now,
             created_or_started_after=created_or_started_after,
+            created_or_started_after_completed_jobs=created_or_started_after_completed_jobs,
             job_kinds=job_kinds,
+            suspended=suspended,
             args=args,
             tag=tag,
             result=result,
+            allow_wildcards=allow_wildcards,
             page=page,
             per_page=per_page,
             is_skipped=is_skipped,
