@@ -17,6 +17,7 @@ def _get_kwargs(
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -35,6 +36,8 @@ def _get_kwargs(
 
     params["scheduled_in_secs"] = scheduled_in_secs
 
+    params["skip_preprocessor"] = skip_preprocessor
+
     params["parent_job"] = parent_job
 
     params["tag"] = tag
@@ -86,6 +89,7 @@ def sync_detailed(
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -100,6 +104,7 @@ def sync_detailed(
         hash_ (str):
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
+        skip_preprocessor (Union[Unset, None, bool]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         cache_ttl (Union[Unset, None, str]):
@@ -122,6 +127,7 @@ def sync_detailed(
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
+        skip_preprocessor=skip_preprocessor,
         parent_job=parent_job,
         tag=tag,
         cache_ttl=cache_ttl,
@@ -145,6 +151,7 @@ async def asyncio_detailed(
     json_body: RunScriptByHashJsonBody,
     scheduled_for: Union[Unset, None, datetime.datetime] = UNSET,
     scheduled_in_secs: Union[Unset, None, int] = UNSET,
+    skip_preprocessor: Union[Unset, None, bool] = UNSET,
     parent_job: Union[Unset, None, str] = UNSET,
     tag: Union[Unset, None, str] = UNSET,
     cache_ttl: Union[Unset, None, str] = UNSET,
@@ -159,6 +166,7 @@ async def asyncio_detailed(
         hash_ (str):
         scheduled_for (Union[Unset, None, datetime.datetime]):
         scheduled_in_secs (Union[Unset, None, int]):
+        skip_preprocessor (Union[Unset, None, bool]):
         parent_job (Union[Unset, None, str]):
         tag (Union[Unset, None, str]):
         cache_ttl (Union[Unset, None, str]):
@@ -181,6 +189,7 @@ async def asyncio_detailed(
         json_body=json_body,
         scheduled_for=scheduled_for,
         scheduled_in_secs=scheduled_in_secs,
+        skip_preprocessor=skip_preprocessor,
         parent_job=parent_job,
         tag=tag,
         cache_ttl=cache_ttl,
