@@ -1,10 +1,8 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
 
-from ..types import UNSET, Unset
-
 T = TypeVar("T", bound="AddOwnerToFolderJsonBody")
 
 
@@ -12,10 +10,10 @@ T = TypeVar("T", bound="AddOwnerToFolderJsonBody")
 class AddOwnerToFolderJsonBody:
     """
     Attributes:
-        owner (Union[Unset, str]):
+        owner (str):
     """
 
-    owner: Union[Unset, str] = UNSET
+    owner: str
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -23,16 +21,18 @@ class AddOwnerToFolderJsonBody:
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
-        if owner is not UNSET:
-            field_dict["owner"] = owner
+        field_dict.update(
+            {
+                "owner": owner,
+            }
+        )
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        owner = d.pop("owner", UNSET)
+        owner = d.pop("owner")
 
         add_owner_to_folder_json_body = cls(
             owner=owner,
