@@ -42,7 +42,7 @@ class CompletedJob:
         parent_job (Union[Unset, str]):
         script_path (Union[Unset, str]):
         script_hash (Union[Unset, str]):
-        args (Union[Unset, CompletedJobArgs]):
+        args (Union[Unset, CompletedJobArgs]): The arguments to pass to the script or flow
         result (Union[Unset, Any]):
         logs (Union[Unset, str]):
         deleted (Union[Unset, bool]):
