@@ -22,6 +22,9 @@ if TYPE_CHECKING:
     from ..models.completed_job_flow_status_preprocessor_module_branchall import (
         CompletedJobFlowStatusPreprocessorModuleBranchall,
     )
+    from ..models.completed_job_flow_status_preprocessor_module_flow_jobs_duration import (
+        CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration,
+    )
     from ..models.completed_job_flow_status_preprocessor_module_iterator import (
         CompletedJobFlowStatusPreprocessorModuleIterator,
     )
@@ -42,6 +45,7 @@ class CompletedJobFlowStatusPreprocessorModule:
         iterator (Union[Unset, CompletedJobFlowStatusPreprocessorModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
         flow_jobs_success (Union[Unset, List[bool]]):
+        flow_jobs_duration (Union[Unset, CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration]):
         branch_chosen (Union[Unset, CompletedJobFlowStatusPreprocessorModuleBranchChosen]):
         branchall (Union[Unset, CompletedJobFlowStatusPreprocessorModuleBranchall]):
         approvers (Union[Unset, List['CompletedJobFlowStatusPreprocessorModuleApproversItem']]):
@@ -60,6 +64,7 @@ class CompletedJobFlowStatusPreprocessorModule:
     iterator: Union[Unset, "CompletedJobFlowStatusPreprocessorModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
     flow_jobs_success: Union[Unset, List[bool]] = UNSET
+    flow_jobs_duration: Union[Unset, "CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration"] = UNSET
     branch_chosen: Union[Unset, "CompletedJobFlowStatusPreprocessorModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "CompletedJobFlowStatusPreprocessorModuleBranchall"] = UNSET
     approvers: Union[Unset, List["CompletedJobFlowStatusPreprocessorModuleApproversItem"]] = UNSET
@@ -100,6 +105,10 @@ class CompletedJobFlowStatusPreprocessorModule:
         if not isinstance(self.flow_jobs_success, Unset):
             flow_jobs_success = self.flow_jobs_success
 
+        flow_jobs_duration: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_jobs_duration, Unset):
+            flow_jobs_duration = self.flow_jobs_duration.to_dict()
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -160,6 +169,8 @@ class CompletedJobFlowStatusPreprocessorModule:
             field_dict["flow_jobs"] = flow_jobs
         if flow_jobs_success is not UNSET:
             field_dict["flow_jobs_success"] = flow_jobs_success
+        if flow_jobs_duration is not UNSET:
+            field_dict["flow_jobs_duration"] = flow_jobs_duration
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
@@ -194,6 +205,9 @@ class CompletedJobFlowStatusPreprocessorModule:
         from ..models.completed_job_flow_status_preprocessor_module_branchall import (
             CompletedJobFlowStatusPreprocessorModuleBranchall,
         )
+        from ..models.completed_job_flow_status_preprocessor_module_flow_jobs_duration import (
+            CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration,
+        )
         from ..models.completed_job_flow_status_preprocessor_module_iterator import (
             CompletedJobFlowStatusPreprocessorModuleIterator,
         )
@@ -220,6 +234,13 @@ class CompletedJobFlowStatusPreprocessorModule:
 
         flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
 
+        _flow_jobs_duration = d.pop("flow_jobs_duration", UNSET)
+        flow_jobs_duration: Union[Unset, CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration]
+        if isinstance(_flow_jobs_duration, Unset):
+            flow_jobs_duration = UNSET
+        else:
+            flow_jobs_duration = CompletedJobFlowStatusPreprocessorModuleFlowJobsDuration.from_dict(_flow_jobs_duration)
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, CompletedJobFlowStatusPreprocessorModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -288,6 +309,7 @@ class CompletedJobFlowStatusPreprocessorModule:
             iterator=iterator,
             flow_jobs=flow_jobs,
             flow_jobs_success=flow_jobs_success,
+            flow_jobs_duration=flow_jobs_duration,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
