@@ -7,6 +7,8 @@ from ..models.create_app_json_body_policy_execution_mode import CreateAppJsonBod
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
+    from ..models.create_app_json_body_policy_allowed_s3_keys_item import CreateAppJsonBodyPolicyAllowedS3KeysItem
+    from ..models.create_app_json_body_policy_s3_inputs_item import CreateAppJsonBodyPolicyS3InputsItem
     from ..models.create_app_json_body_policy_triggerables import CreateAppJsonBodyPolicyTriggerables
     from ..models.create_app_json_body_policy_triggerables_v2 import CreateAppJsonBodyPolicyTriggerablesV2
 
@@ -20,6 +22,8 @@ class CreateAppJsonBodyPolicy:
     Attributes:
         triggerables (Union[Unset, CreateAppJsonBodyPolicyTriggerables]):
         triggerables_v2 (Union[Unset, CreateAppJsonBodyPolicyTriggerablesV2]):
+        s3_inputs (Union[Unset, List['CreateAppJsonBodyPolicyS3InputsItem']]):
+        allowed_s3_keys (Union[Unset, List['CreateAppJsonBodyPolicyAllowedS3KeysItem']]):
         execution_mode (Union[Unset, CreateAppJsonBodyPolicyExecutionMode]):
         on_behalf_of (Union[Unset, str]):
         on_behalf_of_email (Union[Unset, str]):
@@ -27,6 +31,8 @@ class CreateAppJsonBodyPolicy:
 
     triggerables: Union[Unset, "CreateAppJsonBodyPolicyTriggerables"] = UNSET
     triggerables_v2: Union[Unset, "CreateAppJsonBodyPolicyTriggerablesV2"] = UNSET
+    s3_inputs: Union[Unset, List["CreateAppJsonBodyPolicyS3InputsItem"]] = UNSET
+    allowed_s3_keys: Union[Unset, List["CreateAppJsonBodyPolicyAllowedS3KeysItem"]] = UNSET
     execution_mode: Union[Unset, CreateAppJsonBodyPolicyExecutionMode] = UNSET
     on_behalf_of: Union[Unset, str] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
@@ -41,6 +47,22 @@ class CreateAppJsonBodyPolicy:
         if not isinstance(self.triggerables_v2, Unset):
             triggerables_v2 = self.triggerables_v2.to_dict()
 
+        s3_inputs: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.s3_inputs, Unset):
+            s3_inputs = []
+            for s3_inputs_item_data in self.s3_inputs:
+                s3_inputs_item = s3_inputs_item_data.to_dict()
+
+                s3_inputs.append(s3_inputs_item)
+
+        allowed_s3_keys: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.allowed_s3_keys, Unset):
+            allowed_s3_keys = []
+            for allowed_s3_keys_item_data in self.allowed_s3_keys:
+                allowed_s3_keys_item = allowed_s3_keys_item_data.to_dict()
+
+                allowed_s3_keys.append(allowed_s3_keys_item)
+
         execution_mode: Union[Unset, str] = UNSET
         if not isinstance(self.execution_mode, Unset):
             execution_mode = self.execution_mode.value
@@ -55,6 +77,10 @@ class CreateAppJsonBodyPolicy:
             field_dict["triggerables"] = triggerables
         if triggerables_v2 is not UNSET:
             field_dict["triggerables_v2"] = triggerables_v2
+        if s3_inputs is not UNSET:
+            field_dict["s3_inputs"] = s3_inputs
+        if allowed_s3_keys is not UNSET:
+            field_dict["allowed_s3_keys"] = allowed_s3_keys
         if execution_mode is not UNSET:
             field_dict["execution_mode"] = execution_mode
         if on_behalf_of is not UNSET:
@@ -66,6 +92,8 @@ class CreateAppJsonBodyPolicy:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
+        from ..models.create_app_json_body_policy_allowed_s3_keys_item import CreateAppJsonBodyPolicyAllowedS3KeysItem
+        from ..models.create_app_json_body_policy_s3_inputs_item import CreateAppJsonBodyPolicyS3InputsItem
         from ..models.create_app_json_body_policy_triggerables import CreateAppJsonBodyPolicyTriggerables
         from ..models.create_app_json_body_policy_triggerables_v2 import CreateAppJsonBodyPolicyTriggerablesV2
 
@@ -84,6 +112,20 @@ class CreateAppJsonBodyPolicy:
         else:
             triggerables_v2 = CreateAppJsonBodyPolicyTriggerablesV2.from_dict(_triggerables_v2)
 
+        s3_inputs = []
+        _s3_inputs = d.pop("s3_inputs", UNSET)
+        for s3_inputs_item_data in _s3_inputs or []:
+            s3_inputs_item = CreateAppJsonBodyPolicyS3InputsItem.from_dict(s3_inputs_item_data)
+
+            s3_inputs.append(s3_inputs_item)
+
+        allowed_s3_keys = []
+        _allowed_s3_keys = d.pop("allowed_s3_keys", UNSET)
+        for allowed_s3_keys_item_data in _allowed_s3_keys or []:
+            allowed_s3_keys_item = CreateAppJsonBodyPolicyAllowedS3KeysItem.from_dict(allowed_s3_keys_item_data)
+
+            allowed_s3_keys.append(allowed_s3_keys_item)
+
         _execution_mode = d.pop("execution_mode", UNSET)
         execution_mode: Union[Unset, CreateAppJsonBodyPolicyExecutionMode]
         if isinstance(_execution_mode, Unset):
@@ -98,6 +140,8 @@ class CreateAppJsonBodyPolicy:
         create_app_json_body_policy = cls(
             triggerables=triggerables,
             triggerables_v2=triggerables_v2,
+            s3_inputs=s3_inputs,
+            allowed_s3_keys=allowed_s3_keys,
             execution_mode=execution_mode,
             on_behalf_of=on_behalf_of,
             on_behalf_of_email=on_behalf_of_email,
