@@ -33,6 +33,8 @@ class CreateGcpTriggerJsonBody:
         delivery_config (Union[Unset, CreateGcpTriggerJsonBodyDeliveryConfig]):
         enabled (Union[Unset, bool]):
         auto_acknowledge_msg (Union[Unset, bool]):
+        ack_deadline (Union[Unset, int]): Time in seconds within which the message must be acknowledged. If not
+            provided, defaults to the subscription's acknowledgment deadline (600 seconds).
         error_handler_path (Union[Unset, str]):
         error_handler_args (Union[Unset, CreateGcpTriggerJsonBodyErrorHandlerArgs]): The arguments to pass to the script
             or flow
@@ -51,6 +53,7 @@ class CreateGcpTriggerJsonBody:
     delivery_config: Union[Unset, "CreateGcpTriggerJsonBodyDeliveryConfig"] = UNSET
     enabled: Union[Unset, bool] = UNSET
     auto_acknowledge_msg: Union[Unset, bool] = UNSET
+    ack_deadline: Union[Unset, int] = UNSET
     error_handler_path: Union[Unset, str] = UNSET
     error_handler_args: Union[Unset, "CreateGcpTriggerJsonBodyErrorHandlerArgs"] = UNSET
     retry: Union[Unset, "CreateGcpTriggerJsonBodyRetry"] = UNSET
@@ -76,6 +79,7 @@ class CreateGcpTriggerJsonBody:
 
         enabled = self.enabled
         auto_acknowledge_msg = self.auto_acknowledge_msg
+        ack_deadline = self.ack_deadline
         error_handler_path = self.error_handler_path
         error_handler_args: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.error_handler_args, Unset):
@@ -109,6 +113,8 @@ class CreateGcpTriggerJsonBody:
             field_dict["enabled"] = enabled
         if auto_acknowledge_msg is not UNSET:
             field_dict["auto_acknowledge_msg"] = auto_acknowledge_msg
+        if ack_deadline is not UNSET:
+            field_dict["ack_deadline"] = ack_deadline
         if error_handler_path is not UNSET:
             field_dict["error_handler_path"] = error_handler_path
         if error_handler_args is not UNSET:
@@ -159,6 +165,8 @@ class CreateGcpTriggerJsonBody:
 
         auto_acknowledge_msg = d.pop("auto_acknowledge_msg", UNSET)
 
+        ack_deadline = d.pop("ack_deadline", UNSET)
+
         error_handler_path = d.pop("error_handler_path", UNSET)
 
         _error_handler_args = d.pop("error_handler_args", UNSET)
@@ -188,6 +196,7 @@ class CreateGcpTriggerJsonBody:
             delivery_config=delivery_config,
             enabled=enabled,
             auto_acknowledge_msg=auto_acknowledge_msg,
+            ack_deadline=ack_deadline,
             error_handler_path=error_handler_path,
             error_handler_args=error_handler_args,
             retry=retry,
