@@ -27,7 +27,7 @@ class EditSqsTrigger:
         enabled (bool):
         message_attributes (Union[Unset, List[str]]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, EditSqsTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, EditSqsTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, EditSqsTriggerRetry]):
     """
 
