@@ -11,6 +11,8 @@ class FlowModuleValue2Type0Language(str, Enum):
     MSSQL = "mssql"
     MYSQL = "mysql"
     NATIVETS = "nativets"
+    ORACLEDB = "oracledb"
+    PHP = "php"
     POSTGRESQL = "postgresql"
     POWERSHELL = "powershell"
     PYTHON3 = "python3"
