@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class FlowModuleValue2Type5Type(str, Enum):
-    BRANCHALL = "branchall"
+    BRANCHONE = "branchone"
 
     def __str__(self) -> str:
         return str(self.value)
