@@ -12,6 +12,7 @@ if TYPE_CHECKING:
     from ..models.flow_status_module_approvers_item import FlowStatusModuleApproversItem
     from ..models.flow_status_module_branch_chosen import FlowStatusModuleBranchChosen
     from ..models.flow_status_module_branchall import FlowStatusModuleBranchall
+    from ..models.flow_status_module_flow_jobs_duration import FlowStatusModuleFlowJobsDuration
     from ..models.flow_status_module_iterator import FlowStatusModuleIterator
 
 
@@ -30,6 +31,7 @@ class FlowStatusModule:
         iterator (Union[Unset, FlowStatusModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
         flow_jobs_success (Union[Unset, List[bool]]):
+        flow_jobs_duration (Union[Unset, FlowStatusModuleFlowJobsDuration]):
         branch_chosen (Union[Unset, FlowStatusModuleBranchChosen]):
         branchall (Union[Unset, FlowStatusModuleBranchall]):
         approvers (Union[Unset, List['FlowStatusModuleApproversItem']]):
@@ -48,6 +50,7 @@ class FlowStatusModule:
     iterator: Union[Unset, "FlowStatusModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
     flow_jobs_success: Union[Unset, List[bool]] = UNSET
+    flow_jobs_duration: Union[Unset, "FlowStatusModuleFlowJobsDuration"] = UNSET
     branch_chosen: Union[Unset, "FlowStatusModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "FlowStatusModuleBranchall"] = UNSET
     approvers: Union[Unset, List["FlowStatusModuleApproversItem"]] = UNSET
@@ -80,6 +83,10 @@ class FlowStatusModule:
         if not isinstance(self.flow_jobs_success, Unset):
             flow_jobs_success = self.flow_jobs_success
 
+        flow_jobs_duration: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_jobs_duration, Unset):
+            flow_jobs_duration = self.flow_jobs_duration.to_dict()
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -140,6 +147,8 @@ class FlowStatusModule:
             field_dict["flow_jobs"] = flow_jobs
         if flow_jobs_success is not UNSET:
             field_dict["flow_jobs_success"] = flow_jobs_success
+        if flow_jobs_duration is not UNSET:
+            field_dict["flow_jobs_duration"] = flow_jobs_duration
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
@@ -164,6 +173,7 @@ class FlowStatusModule:
         from ..models.flow_status_module_approvers_item import FlowStatusModuleApproversItem
         from ..models.flow_status_module_branch_chosen import FlowStatusModuleBranchChosen
         from ..models.flow_status_module_branchall import FlowStatusModuleBranchall
+        from ..models.flow_status_module_flow_jobs_duration import FlowStatusModuleFlowJobsDuration
         from ..models.flow_status_module_iterator import FlowStatusModuleIterator
 
         d = src_dict.copy()
@@ -188,6 +198,13 @@ class FlowStatusModule:
 
         flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
 
+        _flow_jobs_duration = d.pop("flow_jobs_duration", UNSET)
+        flow_jobs_duration: Union[Unset, FlowStatusModuleFlowJobsDuration]
+        if isinstance(_flow_jobs_duration, Unset):
+            flow_jobs_duration = UNSET
+        else:
+            flow_jobs_duration = FlowStatusModuleFlowJobsDuration.from_dict(_flow_jobs_duration)
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, FlowStatusModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -249,6 +266,7 @@ class FlowStatusModule:
             iterator=iterator,
             flow_jobs=flow_jobs,
             flow_jobs_success=flow_jobs_success,
+            flow_jobs_duration=flow_jobs_duration,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
