@@ -16,6 +16,7 @@ if TYPE_CHECKING:
     from ..models.flow_status_preprocessor_module_approvers_item import FlowStatusPreprocessorModuleApproversItem
     from ..models.flow_status_preprocessor_module_branch_chosen import FlowStatusPreprocessorModuleBranchChosen
     from ..models.flow_status_preprocessor_module_branchall import FlowStatusPreprocessorModuleBranchall
+    from ..models.flow_status_preprocessor_module_flow_jobs_duration import FlowStatusPreprocessorModuleFlowJobsDuration
     from ..models.flow_status_preprocessor_module_iterator import FlowStatusPreprocessorModuleIterator
 
 
@@ -34,6 +35,7 @@ class FlowStatusPreprocessorModule:
         iterator (Union[Unset, FlowStatusPreprocessorModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
         flow_jobs_success (Union[Unset, List[bool]]):
+        flow_jobs_duration (Union[Unset, FlowStatusPreprocessorModuleFlowJobsDuration]):
         branch_chosen (Union[Unset, FlowStatusPreprocessorModuleBranchChosen]):
         branchall (Union[Unset, FlowStatusPreprocessorModuleBranchall]):
         approvers (Union[Unset, List['FlowStatusPreprocessorModuleApproversItem']]):
@@ -52,6 +54,7 @@ class FlowStatusPreprocessorModule:
     iterator: Union[Unset, "FlowStatusPreprocessorModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
     flow_jobs_success: Union[Unset, List[bool]] = UNSET
+    flow_jobs_duration: Union[Unset, "FlowStatusPreprocessorModuleFlowJobsDuration"] = UNSET
     branch_chosen: Union[Unset, "FlowStatusPreprocessorModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "FlowStatusPreprocessorModuleBranchall"] = UNSET
     approvers: Union[Unset, List["FlowStatusPreprocessorModuleApproversItem"]] = UNSET
@@ -91,6 +94,10 @@ class FlowStatusPreprocessorModule:
         if not isinstance(self.flow_jobs_success, Unset):
             flow_jobs_success = self.flow_jobs_success
 
+        flow_jobs_duration: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_jobs_duration, Unset):
+            flow_jobs_duration = self.flow_jobs_duration.to_dict()
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -151,6 +158,8 @@ class FlowStatusPreprocessorModule:
             field_dict["flow_jobs"] = flow_jobs
         if flow_jobs_success is not UNSET:
             field_dict["flow_jobs_success"] = flow_jobs_success
+        if flow_jobs_duration is not UNSET:
+            field_dict["flow_jobs_duration"] = flow_jobs_duration
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
@@ -179,6 +188,9 @@ class FlowStatusPreprocessorModule:
         from ..models.flow_status_preprocessor_module_approvers_item import FlowStatusPreprocessorModuleApproversItem
         from ..models.flow_status_preprocessor_module_branch_chosen import FlowStatusPreprocessorModuleBranchChosen
         from ..models.flow_status_preprocessor_module_branchall import FlowStatusPreprocessorModuleBranchall
+        from ..models.flow_status_preprocessor_module_flow_jobs_duration import (
+            FlowStatusPreprocessorModuleFlowJobsDuration,
+        )
         from ..models.flow_status_preprocessor_module_iterator import FlowStatusPreprocessorModuleIterator
 
         d = src_dict.copy()
@@ -203,6 +215,13 @@ class FlowStatusPreprocessorModule:
 
         flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
 
+        _flow_jobs_duration = d.pop("flow_jobs_duration", UNSET)
+        flow_jobs_duration: Union[Unset, FlowStatusPreprocessorModuleFlowJobsDuration]
+        if isinstance(_flow_jobs_duration, Unset):
+            flow_jobs_duration = UNSET
+        else:
+            flow_jobs_duration = FlowStatusPreprocessorModuleFlowJobsDuration.from_dict(_flow_jobs_duration)
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, FlowStatusPreprocessorModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -266,6 +285,7 @@ class FlowStatusPreprocessorModule:
             iterator=iterator,
             flow_jobs=flow_jobs,
             flow_jobs_success=flow_jobs_success,
+            flow_jobs_duration=flow_jobs_duration,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
