@@ -1,4 +1,4 @@
-from typing import Any, Dict, List, Type, TypeVar, Union
+from typing import Any, Dict, List, Type, TypeVar
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
@@ -6,7 +6,6 @@ from attrs import field as _attrs_field
 from ..models.get_flow_by_path_with_draft_response_200_draft_value_modules_item_sleep_type_0_type import (
     GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0Type,
 )
-from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0")
 
@@ -15,41 +14,39 @@ T = TypeVar("T", bound="GetFlowByPathWithDraftResponse200DraftValueModulesItemSl
 class GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0:
     """
     Attributes:
+        value (Any):
         type (GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0Type):
-        value (Union[Unset, Any]):
     """
 
+    value: Any
     type: GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0Type
-    value: Union[Unset, Any] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
-        type = self.type.value
-
         value = self.value
+        type = self.type.value
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
             {
+                "value": value,
                 "type": type,
             }
         )
-        if value is not UNSET:
-            field_dict["value"] = value
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
+        value = d.pop("value")
+
         type = GetFlowByPathWithDraftResponse200DraftValueModulesItemSleepType0Type(d.pop("type"))
 
-        value = d.pop("value", UNSET)
-
         get_flow_by_path_with_draft_response_200_draft_value_modules_item_sleep_type_0 = cls(
-            type=type,
             value=value,
+            type=type,
         )
 
         get_flow_by_path_with_draft_response_200_draft_value_modules_item_sleep_type_0.additional_properties = d
