@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item import (
         GetHubFlowByIdResponse200FlowValueModulesItem,
     )
+    from ..models.get_hub_flow_by_id_response_200_flow_value_preprocessor_module import (
+        GetHubFlowByIdResponse200FlowValuePreprocessorModule,
+    )
 
 
 T = TypeVar("T", bound="GetHubFlowByIdResponse200FlowValue")
@@ -23,6 +26,7 @@ class GetHubFlowByIdResponse200FlowValue:
     Attributes:
         modules (List['GetHubFlowByIdResponse200FlowValueModulesItem']):
         failure_module (Union[Unset, GetHubFlowByIdResponse200FlowValueFailureModule]):
+        preprocessor_module (Union[Unset, GetHubFlowByIdResponse200FlowValuePreprocessorModule]):
         same_worker (Union[Unset, bool]):
         concurrent_limit (Union[Unset, float]):
         concurrency_key (Union[Unset, str]):
@@ -35,6 +39,7 @@ class GetHubFlowByIdResponse200FlowValue:
 
     modules: List["GetHubFlowByIdResponse200FlowValueModulesItem"]
     failure_module: Union[Unset, "GetHubFlowByIdResponse200FlowValueFailureModule"] = UNSET
+    preprocessor_module: Union[Unset, "GetHubFlowByIdResponse200FlowValuePreprocessorModule"] = UNSET
     same_worker: Union[Unset, bool] = UNSET
     concurrent_limit: Union[Unset, float] = UNSET
     concurrency_key: Union[Unset, str] = UNSET
@@ -56,6 +61,10 @@ class GetHubFlowByIdResponse200FlowValue:
         if not isinstance(self.failure_module, Unset):
             failure_module = self.failure_module.to_dict()
 
+        preprocessor_module: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.preprocessor_module, Unset):
+            preprocessor_module = self.preprocessor_module.to_dict()
+
         same_worker = self.same_worker
         concurrent_limit = self.concurrent_limit
         concurrency_key = self.concurrency_key
@@ -74,6 +83,8 @@ class GetHubFlowByIdResponse200FlowValue:
         )
         if failure_module is not UNSET:
             field_dict["failure_module"] = failure_module
+        if preprocessor_module is not UNSET:
+            field_dict["preprocessor_module"] = preprocessor_module
         if same_worker is not UNSET:
             field_dict["same_worker"] = same_worker
         if concurrent_limit is not UNSET:
@@ -101,6 +112,9 @@ class GetHubFlowByIdResponse200FlowValue:
         from ..models.get_hub_flow_by_id_response_200_flow_value_modules_item import (
             GetHubFlowByIdResponse200FlowValueModulesItem,
         )
+        from ..models.get_hub_flow_by_id_response_200_flow_value_preprocessor_module import (
+            GetHubFlowByIdResponse200FlowValuePreprocessorModule,
+        )
 
         d = src_dict.copy()
         modules = []
@@ -117,6 +131,13 @@ class GetHubFlowByIdResponse200FlowValue:
         else:
             failure_module = GetHubFlowByIdResponse200FlowValueFailureModule.from_dict(_failure_module)
 
+        _preprocessor_module = d.pop("preprocessor_module", UNSET)
+        preprocessor_module: Union[Unset, GetHubFlowByIdResponse200FlowValuePreprocessorModule]
+        if isinstance(_preprocessor_module, Unset):
+            preprocessor_module = UNSET
+        else:
+            preprocessor_module = GetHubFlowByIdResponse200FlowValuePreprocessorModule.from_dict(_preprocessor_module)
+
         same_worker = d.pop("same_worker", UNSET)
 
         concurrent_limit = d.pop("concurrent_limit", UNSET)
@@ -136,6 +157,7 @@ class GetHubFlowByIdResponse200FlowValue:
         get_hub_flow_by_id_response_200_flow_value = cls(
             modules=modules,
             failure_module=failure_module,
+            preprocessor_module=preprocessor_module,
             same_worker=same_worker,
             concurrent_limit=concurrent_limit,
             concurrency_key=concurrency_key,
