@@ -8,10 +8,10 @@ from ..models.get_script_by_path_with_draft_response_200_language import GetScri
 from ..types import UNSET, Unset
 
 if TYPE_CHECKING:
-    from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
-    from ..models.get_script_by_path_with_draft_response_200_fallback_access_types_item import (
-        GetScriptByPathWithDraftResponse200FallbackAccessTypesItem,
+    from ..models.get_script_by_path_with_draft_response_200_assets_item import (
+        GetScriptByPathWithDraftResponse200AssetsItem,
     )
+    from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
     from ..models.get_script_by_path_with_draft_response_200_schema import GetScriptByPathWithDraftResponse200Schema
 
 
@@ -52,7 +52,7 @@ class GetScriptByPathWithDraftResponse200:
         codebase (Union[Unset, str]):
         has_preprocessor (Union[Unset, bool]):
         on_behalf_of_email (Union[Unset, str]):
-        fallback_access_types (Union[Unset, List['GetScriptByPathWithDraftResponse200FallbackAccessTypesItem']]):
+        assets (Union[Unset, List['GetScriptByPathWithDraftResponse200AssetsItem']]):
         draft (Union[Unset, GetScriptByPathWithDraftResponse200Draft]):
     """
 
@@ -86,7 +86,7 @@ class GetScriptByPathWithDraftResponse200:
     codebase: Union[Unset, str] = UNSET
     has_preprocessor: Union[Unset, bool] = UNSET
     on_behalf_of_email: Union[Unset, str] = UNSET
-    fallback_access_types: Union[Unset, List["GetScriptByPathWithDraftResponse200FallbackAccessTypesItem"]] = UNSET
+    assets: Union[Unset, List["GetScriptByPathWithDraftResponse200AssetsItem"]] = UNSET
     draft: Union[Unset, "GetScriptByPathWithDraftResponse200Draft"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
@@ -131,13 +131,13 @@ class GetScriptByPathWithDraftResponse200:
         codebase = self.codebase
         has_preprocessor = self.has_preprocessor
         on_behalf_of_email = self.on_behalf_of_email
-        fallback_access_types: Union[Unset, List[Dict[str, Any]]] = UNSET
-        if not isinstance(self.fallback_access_types, Unset):
-            fallback_access_types = []
-            for fallback_access_types_item_data in self.fallback_access_types:
-                fallback_access_types_item = fallback_access_types_item_data.to_dict()
+        assets: Union[Unset, List[Dict[str, Any]]] = UNSET
+        if not isinstance(self.assets, Unset):
+            assets = []
+            for assets_item_data in self.assets:
+                assets_item = assets_item_data.to_dict()
 
-                fallback_access_types.append(fallback_access_types_item)
+                assets.append(assets_item)
 
         draft: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.draft, Unset):
@@ -203,8 +203,8 @@ class GetScriptByPathWithDraftResponse200:
             field_dict["has_preprocessor"] = has_preprocessor
         if on_behalf_of_email is not UNSET:
             field_dict["on_behalf_of_email"] = on_behalf_of_email
-        if fallback_access_types is not UNSET:
-            field_dict["fallback_access_types"] = fallback_access_types
+        if assets is not UNSET:
+            field_dict["assets"] = assets
         if draft is not UNSET:
             field_dict["draft"] = draft
 
@@ -212,10 +212,10 @@ class GetScriptByPathWithDraftResponse200:
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
-        from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
-        from ..models.get_script_by_path_with_draft_response_200_fallback_access_types_item import (
-            GetScriptByPathWithDraftResponse200FallbackAccessTypesItem,
+        from ..models.get_script_by_path_with_draft_response_200_assets_item import (
+            GetScriptByPathWithDraftResponse200AssetsItem,
         )
+        from ..models.get_script_by_path_with_draft_response_200_draft import GetScriptByPathWithDraftResponse200Draft
         from ..models.get_script_by_path_with_draft_response_200_schema import GetScriptByPathWithDraftResponse200Schema
 
         d = src_dict.copy()
@@ -289,14 +289,12 @@ class GetScriptByPathWithDraftResponse200:
 
         on_behalf_of_email = d.pop("on_behalf_of_email", UNSET)
 
-        fallback_access_types = []
-        _fallback_access_types = d.pop("fallback_access_types", UNSET)
-        for fallback_access_types_item_data in _fallback_access_types or []:
-            fallback_access_types_item = GetScriptByPathWithDraftResponse200FallbackAccessTypesItem.from_dict(
-                fallback_access_types_item_data
-            )
+        assets = []
+        _assets = d.pop("assets", UNSET)
+        for assets_item_data in _assets or []:
+            assets_item = GetScriptByPathWithDraftResponse200AssetsItem.from_dict(assets_item_data)
 
-            fallback_access_types.append(fallback_access_types_item)
+            assets.append(assets_item)
 
         _draft = d.pop("draft", UNSET)
         draft: Union[Unset, GetScriptByPathWithDraftResponse200Draft]
@@ -336,7 +334,7 @@ class GetScriptByPathWithDraftResponse200:
             codebase=codebase,
             has_preprocessor=has_preprocessor,
             on_behalf_of_email=on_behalf_of_email,
-            fallback_access_types=fallback_access_types,
+            assets=assets,
             draft=draft,
         )
 
