@@ -11,6 +11,9 @@ if TYPE_CHECKING:
     )
     from ..models.get_settings_response_200_ai_config_custom_prompts import GetSettingsResponse200AiConfigCustomPrompts
     from ..models.get_settings_response_200_ai_config_default_model import GetSettingsResponse200AiConfigDefaultModel
+    from ..models.get_settings_response_200_ai_config_max_tokens_per_model import (
+        GetSettingsResponse200AiConfigMaxTokensPerModel,
+    )
     from ..models.get_settings_response_200_ai_config_providers import GetSettingsResponse200AiConfigProviders
 
 
@@ -25,12 +28,14 @@ class GetSettingsResponse200AiConfig:
         default_model (Union[Unset, GetSettingsResponse200AiConfigDefaultModel]):
         code_completion_model (Union[Unset, GetSettingsResponse200AiConfigCodeCompletionModel]):
         custom_prompts (Union[Unset, GetSettingsResponse200AiConfigCustomPrompts]):
+        max_tokens_per_model (Union[Unset, GetSettingsResponse200AiConfigMaxTokensPerModel]):
     """
 
     providers: Union[Unset, "GetSettingsResponse200AiConfigProviders"] = UNSET
     default_model: Union[Unset, "GetSettingsResponse200AiConfigDefaultModel"] = UNSET
     code_completion_model: Union[Unset, "GetSettingsResponse200AiConfigCodeCompletionModel"] = UNSET
     custom_prompts: Union[Unset, "GetSettingsResponse200AiConfigCustomPrompts"] = UNSET
+    max_tokens_per_model: Union[Unset, "GetSettingsResponse200AiConfigMaxTokensPerModel"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -50,6 +55,10 @@ class GetSettingsResponse200AiConfig:
         if not isinstance(self.custom_prompts, Unset):
             custom_prompts = self.custom_prompts.to_dict()
 
+        max_tokens_per_model: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.max_tokens_per_model, Unset):
+            max_tokens_per_model = self.max_tokens_per_model.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -61,6 +70,8 @@ class GetSettingsResponse200AiConfig:
             field_dict["code_completion_model"] = code_completion_model
         if custom_prompts is not UNSET:
             field_dict["custom_prompts"] = custom_prompts
+        if max_tokens_per_model is not UNSET:
+            field_dict["max_tokens_per_model"] = max_tokens_per_model
 
         return field_dict
 
@@ -75,6 +86,9 @@ class GetSettingsResponse200AiConfig:
         from ..models.get_settings_response_200_ai_config_default_model import (
             GetSettingsResponse200AiConfigDefaultModel,
         )
+        from ..models.get_settings_response_200_ai_config_max_tokens_per_model import (
+            GetSettingsResponse200AiConfigMaxTokensPerModel,
+        )
         from ..models.get_settings_response_200_ai_config_providers import GetSettingsResponse200AiConfigProviders
 
         d = src_dict.copy()
@@ -106,11 +120,19 @@ class GetSettingsResponse200AiConfig:
         else:
             custom_prompts = GetSettingsResponse200AiConfigCustomPrompts.from_dict(_custom_prompts)
 
+        _max_tokens_per_model = d.pop("max_tokens_per_model", UNSET)
+        max_tokens_per_model: Union[Unset, GetSettingsResponse200AiConfigMaxTokensPerModel]
+        if isinstance(_max_tokens_per_model, Unset):
+            max_tokens_per_model = UNSET
+        else:
+            max_tokens_per_model = GetSettingsResponse200AiConfigMaxTokensPerModel.from_dict(_max_tokens_per_model)
+
         get_settings_response_200_ai_config = cls(
             providers=providers,
             default_model=default_model,
             code_completion_model=code_completion_model,
             custom_prompts=custom_prompts,
+            max_tokens_per_model=max_tokens_per_model,
         )
 
         get_settings_response_200_ai_config.additional_properties = d
