@@ -12,6 +12,9 @@ if TYPE_CHECKING:
     from ..models.list_queue_response_200_item_raw_flow_modules_item_retry_exponential import (
         ListQueueResponse200ItemRawFlowModulesItemRetryExponential,
     )
+    from ..models.list_queue_response_200_item_raw_flow_modules_item_retry_retry_if import (
+        ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf,
+    )
 
 
 T = TypeVar("T", bound="ListQueueResponse200ItemRawFlowModulesItemRetry")
@@ -23,10 +26,12 @@ class ListQueueResponse200ItemRawFlowModulesItemRetry:
     Attributes:
         constant (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetryConstant]):
         exponential (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetryExponential]):
+        retry_if (Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf]):
     """
 
     constant: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemRetryConstant"] = UNSET
     exponential: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemRetryExponential"] = UNSET
+    retry_if: Union[Unset, "ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf"] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -38,6 +43,10 @@ class ListQueueResponse200ItemRawFlowModulesItemRetry:
         if not isinstance(self.exponential, Unset):
             exponential = self.exponential.to_dict()
 
+        retry_if: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.retry_if, Unset):
+            retry_if = self.retry_if.to_dict()
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({})
@@ -45,6 +54,8 @@ class ListQueueResponse200ItemRawFlowModulesItemRetry:
             field_dict["constant"] = constant
         if exponential is not UNSET:
             field_dict["exponential"] = exponential
+        if retry_if is not UNSET:
+            field_dict["retry_if"] = retry_if
 
         return field_dict
 
@@ -56,6 +67,9 @@ class ListQueueResponse200ItemRawFlowModulesItemRetry:
         from ..models.list_queue_response_200_item_raw_flow_modules_item_retry_exponential import (
             ListQueueResponse200ItemRawFlowModulesItemRetryExponential,
         )
+        from ..models.list_queue_response_200_item_raw_flow_modules_item_retry_retry_if import (
+            ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf,
+        )
 
         d = src_dict.copy()
         _constant = d.pop("constant", UNSET)
@@ -72,9 +86,17 @@ class ListQueueResponse200ItemRawFlowModulesItemRetry:
         else:
             exponential = ListQueueResponse200ItemRawFlowModulesItemRetryExponential.from_dict(_exponential)
 
+        _retry_if = d.pop("retry_if", UNSET)
+        retry_if: Union[Unset, ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf]
+        if isinstance(_retry_if, Unset):
+            retry_if = UNSET
+        else:
+            retry_if = ListQueueResponse200ItemRawFlowModulesItemRetryRetryIf.from_dict(_retry_if)
+
         list_queue_response_200_item_raw_flow_modules_item_retry = cls(
             constant=constant,
             exponential=exponential,
+            retry_if=retry_if,
         )
 
         list_queue_response_200_item_raw_flow_modules_item_retry.additional_properties = d
