@@ -1,7 +1,9 @@
+import datetime
 from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union
 
 from attrs import define as _attrs_define
 from attrs import field as _attrs_field
+from dateutil.parser import isoparse
 
 from ..types import UNSET, Unset
 
@@ -28,6 +30,8 @@ class ListResourceResponse200Item:
         is_expired (Union[Unset, bool]):
         refresh_error (Union[Unset, str]):
         account (Union[Unset, float]):
+        created_by (Union[Unset, str]):
+        edited_at (Union[Unset, datetime.datetime]):
     """
 
     path: str
@@ -42,6 +46,8 @@ class ListResourceResponse200Item:
     is_expired: Union[Unset, bool] = UNSET
     refresh_error: Union[Unset, str] = UNSET
     account: Union[Unset, float] = UNSET
+    created_by: Union[Unset, str] = UNSET
+    edited_at: Union[Unset, datetime.datetime] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -60,6 +66,10 @@ class ListResourceResponse200Item:
         is_expired = self.is_expired
         refresh_error = self.refresh_error
         account = self.account
+        created_by = self.created_by
+        edited_at: Union[Unset, str] = UNSET
+        if not isinstance(self.edited_at, Unset):
+            edited_at = self.edited_at.isoformat()
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -86,6 +96,10 @@ class ListResourceResponse200Item:
             field_dict["refresh_error"] = refresh_error
         if account is not UNSET:
             field_dict["account"] = account
+        if created_by is not UNSET:
+            field_dict["created_by"] = created_by
+        if edited_at is not UNSET:
+            field_dict["edited_at"] = edited_at
 
         return field_dict
 
@@ -123,6 +137,15 @@ class ListResourceResponse200Item:
 
         account = d.pop("account", UNSET)
 
+        created_by = d.pop("created_by", UNSET)
+
+        _edited_at = d.pop("edited_at", UNSET)
+        edited_at: Union[Unset, datetime.datetime]
+        if isinstance(_edited_at, Unset):
+            edited_at = UNSET
+        else:
+            edited_at = isoparse(_edited_at)
+
         list_resource_response_200_item = cls(
             path=path,
             resource_type=resource_type,
@@ -136,6 +159,8 @@ class ListResourceResponse200Item:
             is_expired=is_expired,
             refresh_error=refresh_error,
             account=account,
+            created_by=created_by,
+            edited_at=edited_at,
         )
 
         list_resource_response_200_item.additional_properties = d
