@@ -20,6 +20,7 @@ class ListTokensResponse200Item:
         label (Union[Unset, str]):
         expiration (Union[Unset, datetime.datetime]):
         scopes (Union[Unset, List[str]]):
+        email (Union[Unset, str]):
     """
 
     token_prefix: str
@@ -28,6 +29,7 @@ class ListTokensResponse200Item:
     label: Union[Unset, str] = UNSET
     expiration: Union[Unset, datetime.datetime] = UNSET
     scopes: Union[Unset, List[str]] = UNSET
+    email: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -45,6 +47,8 @@ class ListTokensResponse200Item:
         if not isinstance(self.scopes, Unset):
             scopes = self.scopes
 
+        email = self.email
+
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update(
@@ -60,6 +64,8 @@ class ListTokensResponse200Item:
             field_dict["expiration"] = expiration
         if scopes is not UNSET:
             field_dict["scopes"] = scopes
+        if email is not UNSET:
+            field_dict["email"] = email
 
         return field_dict
 
@@ -83,6 +89,8 @@ class ListTokensResponse200Item:
 
         scopes = cast(List[str], d.pop("scopes", UNSET))
 
+        email = d.pop("email", UNSET)
+
         list_tokens_response_200_item = cls(
             token_prefix=token_prefix,
             created_at=created_at,
@@ -90,6 +98,7 @@ class ListTokensResponse200Item:
             label=label,
             expiration=expiration,
             scopes=scopes,
+            email=email,
         )
 
         list_tokens_response_200_item.additional_properties = d
