@@ -32,7 +32,7 @@ class NewMqttTrigger:
         client_version (Union[Unset, NewMqttTriggerClientVersion]):
         enabled (Union[Unset, bool]):
         error_handler_path (Union[Unset, str]):
-        error_handler_args (Union[Unset, NewMqttTriggerErrorHandlerArgs]):
+        error_handler_args (Union[Unset, NewMqttTriggerErrorHandlerArgs]): The arguments to pass to the script or flow
         retry (Union[Unset, NewMqttTriggerRetry]):
     """
 
