@@ -22,6 +22,9 @@ if TYPE_CHECKING:
     from ..models.queued_job_flow_status_preprocessor_module_branchall import (
         QueuedJobFlowStatusPreprocessorModuleBranchall,
     )
+    from ..models.queued_job_flow_status_preprocessor_module_flow_jobs_duration import (
+        QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration,
+    )
     from ..models.queued_job_flow_status_preprocessor_module_iterator import (
         QueuedJobFlowStatusPreprocessorModuleIterator,
     )
@@ -42,6 +45,7 @@ class QueuedJobFlowStatusPreprocessorModule:
         iterator (Union[Unset, QueuedJobFlowStatusPreprocessorModuleIterator]):
         flow_jobs (Union[Unset, List[str]]):
         flow_jobs_success (Union[Unset, List[bool]]):
+        flow_jobs_duration (Union[Unset, QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration]):
         branch_chosen (Union[Unset, QueuedJobFlowStatusPreprocessorModuleBranchChosen]):
         branchall (Union[Unset, QueuedJobFlowStatusPreprocessorModuleBranchall]):
         approvers (Union[Unset, List['QueuedJobFlowStatusPreprocessorModuleApproversItem']]):
@@ -60,6 +64,7 @@ class QueuedJobFlowStatusPreprocessorModule:
     iterator: Union[Unset, "QueuedJobFlowStatusPreprocessorModuleIterator"] = UNSET
     flow_jobs: Union[Unset, List[str]] = UNSET
     flow_jobs_success: Union[Unset, List[bool]] = UNSET
+    flow_jobs_duration: Union[Unset, "QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration"] = UNSET
     branch_chosen: Union[Unset, "QueuedJobFlowStatusPreprocessorModuleBranchChosen"] = UNSET
     branchall: Union[Unset, "QueuedJobFlowStatusPreprocessorModuleBranchall"] = UNSET
     approvers: Union[Unset, List["QueuedJobFlowStatusPreprocessorModuleApproversItem"]] = UNSET
@@ -100,6 +105,10 @@ class QueuedJobFlowStatusPreprocessorModule:
         if not isinstance(self.flow_jobs_success, Unset):
             flow_jobs_success = self.flow_jobs_success
 
+        flow_jobs_duration: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.flow_jobs_duration, Unset):
+            flow_jobs_duration = self.flow_jobs_duration.to_dict()
+
         branch_chosen: Union[Unset, Dict[str, Any]] = UNSET
         if not isinstance(self.branch_chosen, Unset):
             branch_chosen = self.branch_chosen.to_dict()
@@ -160,6 +169,8 @@ class QueuedJobFlowStatusPreprocessorModule:
             field_dict["flow_jobs"] = flow_jobs
         if flow_jobs_success is not UNSET:
             field_dict["flow_jobs_success"] = flow_jobs_success
+        if flow_jobs_duration is not UNSET:
+            field_dict["flow_jobs_duration"] = flow_jobs_duration
         if branch_chosen is not UNSET:
             field_dict["branch_chosen"] = branch_chosen
         if branchall is not UNSET:
@@ -194,6 +205,9 @@ class QueuedJobFlowStatusPreprocessorModule:
         from ..models.queued_job_flow_status_preprocessor_module_branchall import (
             QueuedJobFlowStatusPreprocessorModuleBranchall,
         )
+        from ..models.queued_job_flow_status_preprocessor_module_flow_jobs_duration import (
+            QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration,
+        )
         from ..models.queued_job_flow_status_preprocessor_module_iterator import (
             QueuedJobFlowStatusPreprocessorModuleIterator,
         )
@@ -220,6 +234,13 @@ class QueuedJobFlowStatusPreprocessorModule:
 
         flow_jobs_success = cast(List[bool], d.pop("flow_jobs_success", UNSET))
 
+        _flow_jobs_duration = d.pop("flow_jobs_duration", UNSET)
+        flow_jobs_duration: Union[Unset, QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration]
+        if isinstance(_flow_jobs_duration, Unset):
+            flow_jobs_duration = UNSET
+        else:
+            flow_jobs_duration = QueuedJobFlowStatusPreprocessorModuleFlowJobsDuration.from_dict(_flow_jobs_duration)
+
         _branch_chosen = d.pop("branch_chosen", UNSET)
         branch_chosen: Union[Unset, QueuedJobFlowStatusPreprocessorModuleBranchChosen]
         if isinstance(_branch_chosen, Unset):
@@ -286,6 +307,7 @@ class QueuedJobFlowStatusPreprocessorModule:
             iterator=iterator,
             flow_jobs=flow_jobs,
             flow_jobs_success=flow_jobs_success,
+            flow_jobs_duration=flow_jobs_duration,
             branch_chosen=branch_chosen,
             branchall=branchall,
             approvers=approvers,
