@@ -12,30 +12,40 @@ T = TypeVar("T", bound="RemoveOwnerToFolderJsonBody")
 class RemoveOwnerToFolderJsonBody:
     """
     Attributes:
-        owner (Union[Unset, str]):
+        owner (str):
+        write (Union[Unset, bool]):
     """
 
-    owner: Union[Unset, str] = UNSET
+    owner: str
+    write: Union[Unset, bool] = UNSET
     additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
         owner = self.owner
+        write = self.write
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
-        field_dict.update({})
-        if owner is not UNSET:
-            field_dict["owner"] = owner
+        field_dict.update(
+            {
+                "owner": owner,
+            }
+        )
+        if write is not UNSET:
+            field_dict["write"] = write
 
         return field_dict
 
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
-        owner = d.pop("owner", UNSET)
+        owner = d.pop("owner")
+
+        write = d.pop("write", UNSET)
 
         remove_owner_to_folder_json_body = cls(
             owner=owner,
+            write=write,
         )
 
         remove_owner_to_folder_json_body.additional_properties = d
