@@ -22,26 +22,29 @@ T = TypeVar("T", bound="UpdateScheduleJsonBody")
 class UpdateScheduleJsonBody:
     """
     Attributes:
-        schedule (str):
-        timezone (str):
-        args (UpdateScheduleJsonBodyArgs):
-        on_failure (Union[Unset, str]):
-        on_failure_times (Union[Unset, float]):
-        on_failure_exact (Union[Unset, bool]):
-        on_failure_extra_args (Union[Unset, UpdateScheduleJsonBodyOnFailureExtraArgs]):
-        on_recovery (Union[Unset, str]):
-        on_recovery_times (Union[Unset, float]):
-        on_recovery_extra_args (Union[Unset, UpdateScheduleJsonBodyOnRecoveryExtraArgs]):
-        on_success (Union[Unset, str]):
-        on_success_extra_args (Union[Unset, UpdateScheduleJsonBodyOnSuccessExtraArgs]):
-        ws_error_handler_muted (Union[Unset, bool]):
-        retry (Union[Unset, UpdateScheduleJsonBodyRetry]):
-        no_flow_overlap (Union[Unset, bool]):
-        summary (Union[Unset, str]):
-        description (Union[Unset, str]):
-        tag (Union[Unset, str]):
-        paused_until (Union[Unset, datetime.datetime]):
-        cron_version (Union[Unset, str]):
+        schedule (str): The cron schedule to trigger the script or flow. Should include seconds.
+        timezone (str): The timezone to use for the cron schedule
+        args (UpdateScheduleJsonBodyArgs): The arguments to pass to the script or flow
+        on_failure (Union[Unset, str]): The path to the script or flow to trigger on failure
+        on_failure_times (Union[Unset, float]): The number of times to retry on failure
+        on_failure_exact (Union[Unset, bool]): Whether the schedule should only run on the exact time
+        on_failure_extra_args (Union[Unset, UpdateScheduleJsonBodyOnFailureExtraArgs]): The arguments to pass to the
+            script or flow
+        on_recovery (Union[Unset, str]): The path to the script or flow to trigger on recovery
+        on_recovery_times (Union[Unset, float]): The number of times to retry on recovery
+        on_recovery_extra_args (Union[Unset, UpdateScheduleJsonBodyOnRecoveryExtraArgs]): The arguments to pass to the
+            script or flow
+        on_success (Union[Unset, str]): The path to the script or flow to trigger on success
+        on_success_extra_args (Union[Unset, UpdateScheduleJsonBodyOnSuccessExtraArgs]): The arguments to pass to the
+            script or flow
+        ws_error_handler_muted (Union[Unset, bool]): Whether the WebSocket error handler is muted
+        retry (Union[Unset, UpdateScheduleJsonBodyRetry]): The retry configuration for the schedule
+        no_flow_overlap (Union[Unset, bool]): Whether the schedule should not run if a flow is already running
+        summary (Union[Unset, str]): The summary of the schedule
+        description (Union[Unset, str]): The description of the schedule
+        tag (Union[Unset, str]): The tag of the schedule
+        paused_until (Union[Unset, datetime.datetime]): The date and time the schedule will be paused until
+        cron_version (Union[Unset, str]): The version of the cron schedule to use (last is v2)
     """
 
     schedule: str
